@@ -2,4 +2,4 @@ from dodo_commands.framework.command_error import CommandError  # noqa
 from dodo_commands.framework.config_arg import ConfigArg  # noqa
 from dodo_commands.framework.decorator_scope import DecoratorScope  # noqa
 from dodo_commands.framework.singleton import Dodo  # noqa
-from dodo_commands.framework.util import remove_trailing_dashes  # noqa
+from dodo_commands.framework.util import sh_cmd  # noqa
