@@ -12,11 +12,11 @@ def _args():
 # Use safe=False if the script makes changes other than through Dodo.run
 if Dodo.is_main(__name__, safe=True):
     args = _args()
-    memo = os.environ.get('__DODO_UNIVERSAL_CONFIRM__')
-    os.environ['__DODO_UNIVERSAL_CONFIRM__'] = "1"
+    memo = os.environ.get("__DODO_UNIVERSAL_CONFIRM__")
+    os.environ["__DODO_UNIVERSAL_CONFIRM__"] = "1"
     Dodo.run(["sudo", "service", "docker", "stop"])
     if memo is None:
-        del os.environ['__DODO_UNIVERSAL_CONFIRM__']
+        del os.environ["__DODO_UNIVERSAL_CONFIRM__"]
     else:
-        os.environ['__DODO_UNIVERSAL_CONFIRM__'] = memo
+        os.environ["__DODO_UNIVERSAL_CONFIRM__"] = memo
     Dodo.run(["sudo", "service", "docker", "restart"])
