@@ -5,8 +5,11 @@ from dodo_commands.framework.singleton import Dodo
 # to the list of commands decorated by decorator_name.
 class DecoratorScope:
     def __init__(self, decorator_name, remove=False):
-        self.decorators = Dodo.get('/ROOT').setdefault(
-            'decorators', {}).setdefault(decorator_name, [])
+        self.decorators = (
+            Dodo.get("/ROOT")
+            .setdefault("decorators", {})
+            .setdefault(decorator_name, [])
+        )
         self.prefix = "!" if remove else ""
 
     def __enter__(self):  # noqa
